# eric7.Utilities.ClassBrowsers

Package implementing class browsers for various languages.

Currently it offers class browser support for the following programming languages.

- CORBA IDL
- JavaScript
- ProtoBuf
- Python 3
- Ruby

### Modules

ClbrBaseClasses | Module implementing base classes used by the various class browsers.
ClassBrowsers | Package implementing class browsers for various languages.
pyclbr | Parse a Python file and retrieve classes, functions/methods and attributes.
rbclbr | Parse a Ruby file and retrieve classes, modules, methods and attributes.